@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2018-2019)
+# Copyright (C) Duncan Macleod (2018-2020)
 #
 # This file is part of GWpy.
 #
@@ -25,6 +25,9 @@ import numpy
 
 from matplotlib import (use, rcParams)
 
+# force Agg for all tests
+use('agg', warn=False, force=True)  # noqa
+
 # register custom fixtures for all test modules
 from .testing.fixtures import *  # noqa: F401,F403
 
@@ -36,9 +39,6 @@ numpy.random.seed(1)
 # ignore errors due from pyplot.show() using Agg
 warnings.filterwarnings('ignore', message=".*non-GUI backend.*")
 
-# force Agg for all tests
-use('agg', warn=False, force=True)
-
 # force simpler rcParams for all tests
 # (fixtures or tests may update these individually)
 # NOTE: this most-likely happens _after_ gwpy.plot has
