@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2019)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -299,7 +299,7 @@ class SpectralVariance(Array2D):
             else:
                 bins = numpy.linspace(low, high, num=nbins+1)
         nbins = bins.size-1
-        bins = bins * spectrogram.unit
+        qbins = bins * spectrogram.unit
 
         # loop over frequencies
         out = numpy.zeros((data.shape[1], nbins))
@@ -311,7 +311,7 @@ class SpectralVariance(Array2D):
 
         # return SpectralVariance
         name = '%s variance' % spectrogram.name
-        new = cls(out, bins, epoch=spectrogram.epoch, name=name,
+        new = cls(out, qbins, epoch=spectrogram.epoch, name=name,
                   channel=spectrogram.channel, f0=spectrogram.f0,
                   df=spectrogram.df)
         return new
@@ -352,7 +352,7 @@ class SpectralVariance(Array2D):
         if method == 'imshow':
             raise TypeError("plotting a {0} with {1}() is not "
                             "supported".format(type(self).__name__, method))
-        bins = self.bins
+        bins = self.bins.value
         if (numpy.all(bins > 0) and
                 numpy.allclose(numpy.diff(numpy.log10(bins), n=2), 0)):
             kwargs.setdefault('yscale', 'log')
