@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Scott Coughlin (2017-2019)
+# Copyright (C) Scott Coughlin (2017-2020)
 #
 # This file is part of GWpy.
 #
@@ -19,6 +19,10 @@
 """Extend :mod:`astropy.table` with the `GravitySpyTable`
 """
 
+import os.path
+
+from six.moves.urllib.request import urlopen
+
 from ..utils import mp as mp_utils
 from .table import EventTable
 import numpy as np
@@ -68,7 +72,6 @@ class GravitySpyTable(EventTable):
         -------
         Folder containing omega scans sorted by label
         """
-        from six.moves.urllib.request import urlopen
         import os
         # back to pandas
         try:
@@ -152,28 +155,15 @@ class GravitySpyTable(EventTable):
                            images_for_download_ext, duration,
                            images_for_for_download_path))
 
-        def get_image(url):
-            name = url[3] + '_' + url[4] + '_spectrogram_' + url[5] + '.png'
-            outfile = os.path.join(url[6], url[1], url[2], name)
-            with open(outfile, 'wb') as fout:
-                fout.write(urlopen(url[0]).read())
-
         # calculate maximum number of processes
         nproc = min(kwargs.pop('nproc', 1), len(images))
 
-        # define multiprocessing method
-        def _download_single_image(url):
-            try:
-                return url, get_image(url)
-            except Exception as exc:  # pylint: disable=broad-except
-                if nproc == 1:
-                    raise
-                else:
-                    return url, exc
-
         # read files
         output = mp_utils.multiprocess_with_queues(
-            nproc, _download_single_image, images)
+            nproc,
+            _download_single_image,
+            [(img, nproc) for img in images],
+        )
 
         # raise exceptions (from multiprocessing, single process raises inline)
         for f, x in output:
@@ -212,7 +202,7 @@ class GravitySpyTable(EventTable):
             '/search/similarity_search_restful_API'
 
         map_era_to_url = {
-            'ALL': "event_time BETWEEN 1126400000 AND 1229176818",
+            'ALL': "event_time BETWEEN 1126400000 AND 1584057618",
             'O1': "event_time BETWEEN 1126400000 AND 1137250000",
             'ER10': "event_time BETWEEN 1161907217 AND 1164499217",
             'O2a': "event_time BETWEEN 1164499217 AND 1219276818",
@@ -226,7 +216,7 @@ class GravitySpyTable(EventTable):
             'ifo': "{}".format(", ".join(
                 map(repr, [ifos[i:i+2] for i in range(0, len(ifos), 2)]),
              )),
-            'database': 'updated_similarity_index_v2d0',
+            'database': 'similarity_index_o3',
         }
 
         search = urllib.parse.urlencode(parts)
@@ -240,3 +230,21 @@ class GravitySpyTable(EventTable):
             if exc.code == 500:
                 exc.msg += ', confirm the gravityspy_id is valid'
                 raise
+
+
+def _get_image(url):
+    name = "{0[3]}_{0[4]}_spectrogram_{0[5]}.png".format(url)
+    outfile = os.path.join(url[6], url[1], url[2], name)
+    with open(outfile, 'wb') as fout:
+        fout.write(urlopen(url[0]).read())
+
+
+def _download_single_image(bundle):
+    url, nproc = bundle
+    try:
+        return url, _get_image(url)
+    except Exception as exc:  # pylint: disable=broad-except
+        if nproc == 1:
+            raise
+        else:
+            return url, exc
