@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2019)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -19,6 +19,7 @@
 """Unit tests for `gwpy.table`
 """
 
+from socket import timeout
 from ssl import SSLError
 
 from six.moves.urllib.error import URLError
@@ -57,8 +58,12 @@ class TestGravitySpyTable(_TestEventTable):
 
     def test_search(self):
         try:
-            table = self.TABLE.search(gravityspy_id="8FHTgA8MEu", howmany=1)
-        except (URLError, SSLError) as e:
+            table = self.TABLE.search(
+                gravityspy_id="8FHTgA8MEu",
+                howmany=1,
+                remote_timeout=60,
+            )
+        except (URLError, SSLError, timeout) as e:
             pytest.skip(str(e))
 
         utils.assert_table_equal(table, self.TABLE(JSON_RESPONSE))
