@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2019)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -243,7 +243,7 @@ class TestTable(object):
             assert str(exc.value) == ('document must contain exactly '
                                       'one sngl_burst table')
 
-    @utils.skip_missing_dependency('glue.ligolw.lsctables')
+    @utils.skip_missing_dependency('ligo.lw.lsctables')
     def test_read_write_ligolw_ilwdchar_compat(self):
         from glue.ligolw.ilwd import get_ilwdchar_class
         from glue.ligolw.lsctables import SnglBurstTable
@@ -343,6 +343,7 @@ class TestTable(object):
                                  ('time', filters.in_segmentlist, segs)),
             )
 
+    @utils.skip_missing_dependency('LDAStools.frameCPP')
     def test_read_write_gwf(self):
         table = self.create(100, ['time', 'blah', 'frequency'])
         columns = table.dtype.names
@@ -350,11 +351,11 @@ class TestTable(object):
             # check write
             try:
                 table.write(tmp, 'test_read_write_gwf')
-            except ImportError as exc:  # no frameCPP
-                pytest.skip(str(exc))
             except TypeError as exc:  # frameCPP broken (2.6.7)
                 if 'ParamList' in str(exc):
-                    pytest.skip("bug in python-ldas-tools-framecpp")
+                    pytest.skip(
+                        "bug in python-ldas-tools-framecpp: {!s}".format(exc),
+                    )
                 raise
 
             # check read gives back same table
@@ -443,22 +444,29 @@ class TestEventTable(TestTable):
             table.filter(('time', filters.not_in_segmentlist, SegmentList())))
 
     def test_event_rates(self, table):
+        """Test :meth:`gwpy.table.EventTable.event_rate`
+        """
         rate = table.event_rate(1)
         assert isinstance(rate, TimeSeries)
         assert rate.sample_rate == 1 * units.Hz
 
-        # repeat with object dtype
-        try:
-            from lal import LIGOTimeGPS as LalGps
-        except ImportError:
-            return
+    @utils.skip_missing_dependency('lal')
+    def test_event_rates_gpsobject(self, table):
+        """Test that `EventTable.event_rate` can handle object dtypes
+        """
+        rate = table.event_rate(1)
+
+        from lal import LIGOTimeGPS as LalGps
         lgps = list(map(LalGps, table['time']))
         t2 = type(table)(data=[lgps], names=['time'])
         rate2 = t2.event_rate(1, start=table['time'].min())
+
         utils.assert_quantity_sub_equal(rate, rate2)
 
-        # check that method can function without explicit time column
-        # (and no data) if and only if start/end are both given
+    def test_event_rates_start_end(self):
+        """Check that `EventTable.event_rate` can function without explicit time column
+        (and no data) if and only if start/end are both given
+        """
         t2 = self.create(10, names=['a', 'b'])
         with pytest.raises(ValueError) as exc:
             t2.event_rate(1)
@@ -657,7 +665,7 @@ class TestEventTable(TestTable):
 
             # add another IFO, then assert that reading the table without
             # specifying the IFO fails
-            with h5py.File(fp) as h5f:
+            with h5py.File(fp, "r+") as h5f:
                 h5f.create_group('Z1')
             with pytest.raises(ValueError) as exc:
                 self.TABLE.read(fp, format="hdf5.pycbc_live")
@@ -740,34 +748,40 @@ class TestEventTable(TestTable):
             if os.path.isdir(os.path.dirname(fp)):
                 shutil.rmtree(os.path.dirname(fp))
 
-    def test_fetch_hacr(self):
+    @pytest.fixture(scope="module")
+    def hacr_table(self):
+        """Create a table of HACR-like data, and patch
+        `pymysql.connect` to return it
+        """
         table = self.create(100, names=HACR_COLUMNS)
+        connect = mock.patch(
+            "pymysql.connect",
+            return_value=mock_hacr_connection(table, 123, 456),
+        )
         try:
-            from pymysql import connect  # noqa: F401
-        except ImportError:
-            mockee = 'gwpy.table.io.hacr.connect'
-        else:
-            mockee = 'pymysql.connect'
-        with mock.patch(mockee) as mock_connect:
-            mock_connect.return_value = mock_hacr_connection(
-                table, 123, 456)
+            connect.start()
+        except ImportError as exc:
+            pytest.skip(str(exc))
+        yield table
+        connect.stop()
 
-            # test simple query returns the full table
-            t2 = self.TABLE.fetch('hacr', 'X1:TEST-CHANNEL', 123, 456)
-            utils.assert_table_equal(table, t2)
+    def test_fetch_hacr(self, hacr_table):
+        t2 = self.TABLE.fetch('hacr', 'X1:TEST-CHANNEL', 123, 456)
 
-            # test column selection works
-            t2 = self.TABLE.fetch('hacr', 'X1:TEST-CHANNEL', 123, 456,
-                                  columns=['gps_start', 'snr'])
-            utils.assert_table_equal(table['gps_start', 'snr'], t2)
+        # check type matches
+        assert type(t2) is self.TABLE
 
-            # test column selection works
-            t2 = self.TABLE.fetch('hacr', 'X1:TEST-CHANNEL', 123, 456,
-                                  columns=['gps_start', 'snr'],
-                                  selection='freq_central>500')
-            utils.assert_table_equal(
-                filter_table(table, 'freq_central>500')['gps_start', 'snr'],
-                t2)
+        # check response is correct
+        utils.assert_table_equal(hacr_table, t2)
+
+    def test_fetch_hacr_columns(self, hacr_table):
+        t2 = self.TABLE.fetch('hacr', 'X1:TEST-CHANNEL', 123, 456,
+                              columns=['gps_start', 'snr'],
+                              selection='freq_central>500')
+        utils.assert_table_equal(
+            filter_table(hacr_table, 'freq_central>500')['gps_start', 'snr'],
+            t2,
+        )
 
     def test_fetch_open_data(self):
         try:
