@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2019)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -325,8 +325,8 @@ class TimeSeries(TimeSeriesBase):
 
         Returns
         -------
-        psd :  `~gwpy.frequencyseries.FrequencySeries`
-            a data series containing the PSD.
+        asd :  `~gwpy.frequencyseries.FrequencySeries`
+            a data series containing the ASD
 
         See also
         --------
@@ -493,9 +493,13 @@ class TimeSeries(TimeSeriesBase):
         # set kwargs for periodogram()
         kwargs.setdefault('fs', self.sample_rate.to('Hz').value)
         # run
-        return spectral.spectrogram(self, signal.periodogram,
-                                    fftlength=fftlength, overlap=overlap,
-                                    window=window, **kwargs)
+        return spectral.spectrogram(
+            self,
+            fftlength=fftlength,
+            overlap=overlap,
+            window=window,
+            **kwargs
+        )
 
     def fftgram(self, fftlength, overlap=None, window='hann', **kwargs):
         """Calculate the Fourier-gram of this `TimeSeries`.
