@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2018-2019)
+# Copyright (C) Duncan Macleod (2018-2020)
 #
 # This file is part of GWpy.
 #
@@ -204,5 +204,14 @@ class TestArray2D(_TestSeries):
         with pytest.raises(IndexError):
             array.value_at(1.6, 4.8)
 
+    @pytest.mark.skip("not implemented for >1D arrays")
     def test_pad(self):
         return NotImplemented
+
+    @pytest.mark.skip("not implemented for >1D arrays")
+    def test_pad_index(self):
+        return NotImplemented
+
+    @pytest.mark.skip("not implemented for >1D arrays")
+    def test_pad_asymmetric(self):
+        return NotImplemented
